/***************************************************************************
                          qconfig.cpp  -  description
                             -------------------
    begin                : Tue Apr 11 2000
    copyright            : (C) 2000 by Christian Rossi
    email                : crossi@mailcity.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qstring.h>
#include <qfile.h>
#include <qtextstream.h>
#include "qconfig.h"

QConfig::QConfig(QString nombreArchivo)
{
	File = new QFile(nombreArchivo);
	File->open(IO_ReadWrite);
	cantidadGrupos = -1;
	leerArchivo();
}

QConfig::~QConfig()
{
	guardarArchivo();
	File->close();
	delete File;
}

/**************************************
* Devuelve el grupo en donde se       *
* estan buscando las claves           *
***************************************/
QString * QConfig::group()
{
	return &grupos[grupoActual].nombre;
}

/**************************************
* Especifica el grupo en donde se van *
* a buscar las claves                 *
***************************************/
void QConfig::setGroup(char group[256])
{
	int			i;
	QString	Auxiliar;
	
	Auxiliar = "[";
	Auxiliar.operator+=(group);		
	Auxiliar.operator+=("]");			
	
	for (i=0;i<cantidadGrupos;i++)
	{
		if(operator==(Auxiliar,grupos[i].nombre))
		{
			grupoActual = i;
			return;
		}
	}
	
	grupos[cantidadGrupos].nombre = Auxiliar;
	grupos[cantidadGrupos].cantidadClaves=0;
	grupoActual=cantidadGrupos;
	cantidadGrupos++;	
		
	return;
}

/*******************************************
* Lee el archivo y lo carga en la variable *
* config                                   *
********************************************/
void QConfig::leerArchivo()
{
	QTextStream t(File);        // use a text stream
	QString			s;

	while (!t.eof())        // until end of file...
	{
		s = t.readLine();       // line of text excluding '\n'
		if (!s.isEmpty())		
		{
			if (s.operator[](0)=='[')
			{
				// incrementa en uno el numero final de claves
				if (cantidadGrupos != -1)
					grupos[cantidadGrupos].cantidadClaves++;
				// Apunto al proximo grupo
				cantidadGrupos++;
				// Salva el nombre del grupo
				grupos[cantidadGrupos].nombre = s;
				// Inicializa la cantidad de LLaves
				grupos[cantidadGrupos].cantidadClaves = -1;
			}
			else
			{
				// Avanza el numero de Claves
				grupos[cantidadGrupos].cantidadClaves++;
				// Salva la clave
				grupos[cantidadGrupos].claves[grupos[cantidadGrupos].cantidadClaves].clave = s.left(s.find('=',0,true));
				// Salva el valor
				grupos[cantidadGrupos].claves[grupos[cantidadGrupos].cantidadClaves].valor = s.right(strlen(s)-s.find('=',0,true)-1);
			}
		}
	}
	// incrementa en uno el numero final de Claves
	grupos[cantidadGrupos].cantidadClaves++;
	// incrementa en uno el numero final de Grupos
	cantidadGrupos++;
}

/*******************************************
* Lee la variable config y lo guarda en el *
* archivo                                  *
********************************************/
void QConfig::guardarArchivo()
{
	int					i;
	int					j;
	QString			Auxiliar;
	
	File->close();
	File->remove();
	File->open(IO_ReadWrite);

	QTextStream t(File);        // use a text stream	
			
	for (i=0;i<cantidadGrupos;i++)
	{
		t.writeRawBytes(grupos[i].nombre,strlen(grupos[i].nombre));
		t.writeRawBytes("\n",1);
		for (j=0;j<grupos[i].cantidadClaves;j++)
		{
			Auxiliar = grupos[i].claves[j].clave;
			Auxiliar.operator+=("=");
			Auxiliar.operator+=(grupos[i].claves[j].valor);
			Auxiliar.operator+=("\n");		
			t.writeRawBytes(Auxiliar,strlen(Auxiliar));
		}
	}
}

/**************************************
* Agrega una clave en el grupo actual *
***************************************/

void QConfig::escribirEntrada(char clave[256],char valor[256])
{
	int			i;
	
	for (i=0;i<grupos[grupoActual].cantidadClaves;i++)
	{
		if(operator==(clave,grupos[grupoActual].claves[i].clave))
		{
			grupos[grupoActual].claves[i].valor = valor;
			return;
		}
	}
		
	grupos[grupoActual].claves[grupos[grupoActual].cantidadClaves].valor = valor;
	grupos[grupoActual].claves[grupos[grupoActual].cantidadClaves].clave = clave;
	grupos[grupoActual].cantidadClaves++;
}
/****************************************
* Lee una entrada desde el grupo actual *
*****************************************/
QString QConfig::leerEntrada(char clave[256])
{
	int			i;
	
	for (i=0;i<grupos[grupoActual].cantidadClaves;i++)
	{
		if(operator==(clave,grupos[grupoActual].claves[i].clave))
			return grupos[grupoActual].claves[i].valor;

	}
	return "";
}
